<template>
  <Dialog v-model="dialogVisible" :title="dialogTitle" width="50%">
    <el-form
      ref="formRef"
      v-loading="formLoading"
      :model="formData"
      :rules="formRules"
      label-width="120px"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="测点编码" prop="pointNo">
            <el-input v-model="formData.pointNo" placeholder="请输入测点编码" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="测点名称" prop="pointName">
            <el-input v-model="formData.pointName" placeholder="请输入测点名称" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="测点类型" prop="pointType">
            <el-input v-model="formData.pointType" placeholder="请输入测点类型" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="数据类型" prop="dataType">
            <el-input v-model="formData.dataType" placeholder="请输入数据类型" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="值类型" prop="valueType">
            <el-input v-model="formData.valueType" placeholder="请输入值类型" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="存储类型" prop="storeType">
            <el-input v-model="formData.storeType" placeholder="请输入存储类型" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="测量单位" prop="unit">
            <el-input v-model="formData.unit" placeholder="请输入测量单位" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="单位转换" prop="unittransfactor">
            <el-input v-model="formData.unittransfactor" placeholder="请输入单位转换" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="默认值" prop="defaultValue">
            <el-input v-model="formData.defaultValue" placeholder="请输入默认值" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="最大值" prop="maxValue">
            <el-input v-model="formData.maxValue" placeholder="请输入最大值" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="最小值" prop="minValue">
            <el-input v-model="formData.minValue" placeholder="请输入最小值" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="采集频率" prop="minfreqid">
            <el-input v-model="formData.minfreqid" placeholder="请输入采集频率" />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="备注" prop="remark">
            <el-input v-model="formData.remark" placeholder="请输入备注" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="是否启用" prop="isEnable">
            <el-input v-model="formData.isEnable" placeholder="请输入是否启用" />
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template #footer>
      <el-button :disabled="formLoading" type="primary" @click="submitForm">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script lang="ts" setup>
import * as DaPoint from '@/api/data/da/point'

defineOptions({ name: 'DataDaPointForm' })

  const { t } = useI18n() // 国际化
  const message = useMessage() // 消息弹窗
  const dialogVisible = ref(false) // 弹窗的是否展示
  const dialogTitle = ref('') // 弹窗的标题
  const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
  const formType = ref('') // 表单的类型：create - 新增；update - 修改
  const formData = ref({
    id: undefined,
    pointNo: undefined,
    pointName: undefined,
    pointType: undefined,
    dataType: undefined,
    valueType: undefined,
    storeType: undefined,
    unit: undefined,
    unittransfactor: undefined,
    defaultValue: undefined,
    maxValue: undefined,
    minValue: undefined,
    minfreqid: undefined,
    remark: undefined,
    isEnable: undefined,
  })
  const formRules = reactive({
    pointNo: [{ required: true, message: '测点编码不能为空', trigger: 'blur' }],
    pointName: [{ required: true, message: '测点名称不能为空', trigger: 'blur' }],
  })
  const formRef = ref() // 表单 Ref

  /** 打开弹窗 */
  const open = async (type: string, id?: number) => {
    dialogVisible.value = true
    dialogTitle.value = t('action.' + type)
    formType.value = type
    resetForm()
    // 修改时，设置数据
    if (id) {
      formLoading.value = true
      try {
        formData.value = await DaPoint.getDaPoint(id)
      } finally {
        formLoading.value = false
      }
    }
  }
  defineExpose({ open }) // 提供 open 方法，用于打开弹窗

  /** 提交表单 */
  const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
  const submitForm = async () => {
    // 校验表单
    if (!formRef) return
    const valid = await formRef.value.validate()
    if (!valid) return
    // 提交请求
    formLoading.value = true
    try {
      const data = formData.value as unknown as DaPoint.DaPointVO
      if (formType.value === 'create') {
        await DaPoint.createDaPoint(data)
        message.success(t('common.createSuccess'))
      } else {
        await DaPoint.updateDaPoint(data)
        message.success(t('common.updateSuccess'))
      }
      dialogVisible.value = false
      // 发送操作成功的事件
      emit('success')
    } finally {
      formLoading.value = false
    }
  }

  /** 重置表单 */
  const resetForm = () => {
    formData.value = {
      id: undefined,
      pointNo: undefined,
      pointName: undefined,
      pointType: undefined,
      dataType: undefined,
      valueType: undefined,
      storeType: undefined,
      unit: undefined,
      unittransfactor: undefined,
      defaultValue: undefined,
      maxValue: undefined,
      minValue: undefined,
      minfreqid: undefined,
      remark: undefined,
      isEnable: undefined,
    }
    formRef.value?.resetFields()
  }
</script>
